<?php
/**
 * Counter Section
 *
 * @package Travellable
 */

$wp_customize->add_section(
	'travellable_counter_section',
	array(
		'panel' => 'travellable_front_page_options',
		'title' => esc_html__( 'Counter Section', 'travellable' ),
	)
);

// Counter Section - Enable Section.
$wp_customize->add_setting(
	'travellable_enable_counter_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'travellable_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Travellable_Toggle_Switch_Custom_Control(
		$wp_customize,
		'travellable_enable_counter_section',
		array(
			'label'    => esc_html__( 'Enable Counter Section', 'travellable' ),
			'section'  => 'travellable_counter_section',
			'settings' => 'travellable_enable_counter_section',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'travellable_enable_counter_section',
		array(
			'selector' => '#travellable_counter_section .section-link',
			'settings' => 'travellable_enable_counter_section',
		)
	);
}

// Counter Section - Section Title.
$wp_customize->add_setting(
	'travellable_counter_section_title',
	array(
		'default'           => __( 'Why choose us?', 'travellable' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'travellable_counter_section_title',
	array(
		'label'           => esc_html__( 'Section Title', 'travellable' ),
		'section'         => 'travellable_counter_section',
		'settings'        => 'travellable_counter_section_title',
		'type'            => 'text',
		'active_callback' => 'travellable_is_counter_section_enabled',
	)
);

// Counter Section - Background Image.
$wp_customize->add_setting(
	'travellable_counter_background',
	array(
		'sanitize_callback' => 'travellable_sanitize_image',
	)
);

$wp_customize->add_control(
	new WP_Customize_Image_Control(
		$wp_customize,
		'travellable_counter_background',
		array(
			'label'           => esc_html__( 'Background Image', 'travellable' ),
			'section'         => 'travellable_counter_section',
			'settings'        => 'travellable_counter_background',
			'active_callback' => 'travellable_is_counter_section_enabled',
		)
	)
);

// Counter Section - Number of Counters.
$wp_customize->add_setting(
	'travellable_counter_count',
	array(
		'default'           => 4,
		'sanitize_callback' => 'travellable_sanitize_number_range',
		'validate_callback' => 'travellable_validate_counter_count',
	)
);

$wp_customize->add_control(
	'travellable_counter_count',
	array(
		'label'           => esc_html__( 'Number of Counters', 'travellable' ),
		'description'     => esc_html__( 'Note: Min 2 & Max 4. Please input the valid number and save. Then refresh the page to see the change.', 'travellable' ),
		'section'         => 'travellable_counter_section',
		'settings'        => 'travellable_counter_count',
		'type'            => 'number',
		'input_attrs'     => array(
			'min' => 2,
			'max' => 4,
		),
		'active_callback' => 'travellable_is_counter_section_enabled',
	)
);

// List out selected number of fields.
$counter_count = get_theme_mod( 'travellable_counter_count', 4 );

for ( $i = 1; $i <= $counter_count; $i++ ) {

	$wp_customize->add_setting(
		'travellable_counter_label_' . $i,
		array(
			'default'           => '',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'travellable_counter_label_' . $i,
		array(
			'label'           => esc_html__( 'Label ', 'travellable' ) . $i,
			'section'         => 'travellable_counter_section',
			'settings'        => 'travellable_counter_label_' . $i,
			'type'            => 'text',
			'active_callback' => 'travellable_is_counter_section_enabled',
		)
	);

	$wp_customize->add_setting(
		'travellable_counter_value_' . $i,
		array(
			'default'           => '',
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'travellable_counter_value_' . $i,
		array(
			'label'           => esc_html__( 'Value ', 'travellable' ) . $i,
			'section'         => 'travellable_counter_section',
			'settings'        => 'travellable_counter_value_' . $i,
			'type'            => 'number',
			'input_attrs'     => array( 'min' => 1 ),
			'active_callback' => 'travellable_is_counter_section_enabled',
		)
	);

	$wp_customize->add_setting(
		'travellable_counter_value_suffix_' . $i,
		array(
			'default'           => '',
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control(
		'travellable_counter_value_suffix_' . $i,
		array(
			'label'           => esc_html__( 'Value Suffix ', 'travellable' ) . $i,
			'section'         => 'travellable_counter_section',
			'settings'        => 'travellable_counter_value_suffix_' . $i,
			'type'            => 'text',
			'active_callback' => 'travellable_is_counter_section_enabled',
		)
	);

}
